@@ -3,7 +3,7 @@ package Net::DNS::Nameserver;
 use strict;
 use warnings;
 
-our $VERSION = (qw$Id: Nameserver.pm 1957 2024-01-10 14:54:10Z willem $)[2];
+our $VERSION = (qw$Id: Nameserver.pm 1959 2024-01-17 08:55:01Z willem $)[2];
 
 
 =head1 NAME
@@ -720,10 +720,10 @@ zonefile data served by an embedded Net::DNS::Nameserver instance.
     use strict;
     use warnings;
     use Test::More;
-    use Net::DNS::Nameserver;
 
     plan skip_all => 'Net::DNS::Nameserver not available'
-		unless Net::DNS::Nameserver->can('start_server');
+		unless eval { require Net::DNS::Nameserver }
+		and Net::DNS::Nameserver->can('start_server');
     plan tests => 2;
 
     my $resolver = Net::DNS::Resolver->new(
