@@ -1,81 +1,74 @@
 package Net::DNS::RR::LP;
 
-#
-# $Id: LP.pm 1381 2015-08-25 07:36:09Z willem $
-#
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1381 $)[1];
-
-
 use strict;
+use warnings;
+our $VERSION = (qw$Id: LP.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::LP - DNS LP resource record
 
 =cut
 
-
 use integer;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset ) = @_;
+	my ( $self, $data, $offset ) = @_;
 
 	$self->{preference} = unpack( "\@$offset n", $$data );
-	$self->{target} = decode Net::DNS::DomainName( $data, $offset + 2 );
+	$self->{target}	    = Net::DNS::DomainName->decode( $data, $offset + 2 );
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless $self->{target};
-	my $rdata = pack 'n', $self->preference;
-	$rdata .= $self->{target}->encode();
+	my $target = $self->{target};
+	return pack 'n a*', $self->preference, $target->encode();
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless $self->{target};
-	join ' ', $self->preference, $self->{target}->string;
+	my $target = $self->{target};
+	return join ' ', $self->preference, $target->string;
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
-	$self->preference(shift);
-	$self->target(shift);
+	for (qw(preference target)) { $self->$_( shift @argument ) }
+	return;
 }
 
 
 sub preference {
-	my $self = shift;
-
-	$self->{preference} = 0 + shift if scalar @_;
-	$self->{preference} || 0;
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{preference} = 0 + $_ }
+	return $self->{preference} || 0;
 }
 
 
 sub target {
-	my $self = shift;
-
-	$self->{target} = new Net::DNS::DomainName(shift) if scalar @_;
-	$self->{target}->name if defined wantarray && $self->{target};
+	my ( $self, @value ) = @_;
+	for (@value) { $self->{target} = Net::DNS::DomainName->new($_) }
+	return $self->{target} ? $self->{target}->name : undef;
 }
 
 
-sub FQDN { shift->{target}->fqdn; }
-sub fqdn { shift->{target}->fqdn; }
+sub FQDN { return shift->{target}->fqdn; }
+sub fqdn { return shift->{target}->fqdn; }
 
 
 my $function = sub {			## sort RRs in numerically ascending order.
-	$Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'};
+	return $Net::DNS::a->{'preference'} <=> $Net::DNS::b->{'preference'};
 };
 
 __PACKAGE__->set_rrsort_func( 'preference', $function );
@@ -90,9 +83,9 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name IN LP preference FQDN');
+    $rr = Net::DNS::RR->new('name IN LP preference FQDN');
 
-    $rr = new Net::DNS::RR(
+    $rr = Net::DNS::RR->new(
 	name	   => 'example.com',
 	type	   => 'LP',
 	preference => 10,
@@ -130,7 +123,6 @@ higher values.
 
 =head2 FQDN, fqdn
 
-
 =head2 target
 
     $target = $rr->target;
@@ -153,7 +145,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -170,6 +162,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC6742
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC6742|https://tools.ietf.org/html/rfc6742>
 
 =cut
